%global _hardened_build 1

Name:           kannel
Summary:        WAP and SMS gateway
Version:        1.4.3
Release:        21%{?dist}
License:        BSD
URL:            http://www.kannel.org/
Source0:        http://www.kannel.org/download/%{version}/gateway-%{version}.tar.bz2
Source1:        kannel.logrotate
Source2:        kannel-bearerbox.service
Source3:        kannel.conf
Source4:        gw-config
Source5:        kannel-wapbox.service
Source6:        kannel-smsbox.service
# TODO: a corresponding configure.in patch could be upstreamable?
Patch0:         gateway-1.4.3-ssldetect.patch
Patch1:         gateway-1.4.1-typesh.patch
Patch2:         log-arm-587.patch

BuildRequires:  bison
BuildRequires:  byacc
BuildRequires:  docbook-dtds
BuildRequires:  docbook-style-dsssl
BuildRequires:  flex
BuildRequires:  ghostscript
BuildRequires:  ImageMagick
BuildRequires:  jadetex
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  sqlite-devel
#BuildRequires:  tetex-dvips
#BuildRequires:  texlive-fancyhdr
#BuildRequires:  texlive-metafont-bin
#BuildRequires:  texlive-passivetex
#BuildRequires:  texlive-texconfig-bin
BuildRequires:  texlive-collection-basic
BuildRequires:  texlive-collection-genericrecommended
BuildRequires:  texlive-collection-htmlxml
BuildRequires:  texlive-collection-latex
Requires(pre):  shadow-utils
BuildRequires:  systemd
BuildRequires:  transfig
BuildRequires:  zlib-devel
%{?_with_mysql:Buildrequires:  mysql-devel}
%{?_with_pgsql:Buildrequires:  postgresql-devel}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
# For triggerun
Requires(post): systemd-sysv

%description
The Kannel Open Source WAP and SMS gateway works as both an SMS gateway, for
implementing keyword based services via GSM text messages, and a WAP gateway,
via UDP. The SMS part is fairly mature, the WAP part is early in its
development. In this release, the GET request for WML pages and WMLScript
files via HTTP works, including compilation for WML and WMLScript to binary
forms. Only the data call bearer (UDP) is supported, not SMS.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-static = %{version}-%{release}

%description    devel
The Kannel Open Source WAP and SMS gateway works as both an SMS gateway, for
implementing keyword based services via GSM text messages, and a WAP gateway,
via UDP. The SMS part is fairly mature, the WAP part is early in its
development. In this release, the GET request for WML pages and WMLScript
files via HTTP works, including compilation for WML and WMLScript to binary
forms. Only the data call bearer (UDP) is supported, not SMS.

Install this package if you need to develop or recompile applications that
use the Kannel WAP and SMS gateway.

%package        docs
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    docs
The Kannel Open Source WAP and SMS gateway works as both an SMS gateway, for
implementing keyword based services via GSM text messages, and a WAP gateway,
via UDP. The SMS part is fairly mature, the WAP part is early in its
development. In this release, the GET request for WML pages and WMLScript
files via HTTP works, including compilation for WML and WMLScript to binary
forms. Only the data call bearer (UDP) is supported, not SMS.

This package contains documentation for the Kannel WAP and SMS gateway.

%prep
%setup -q -n gateway-%{version}
%patch0 -p1 -b .ssldetect
%patch1 -p1 -b .typesh
%patch2 -p1 -b .arm
chmod -c -x gwlib/html-entities.def # for -debuginfo, as of 1.4.3

%build
%configure \
    --enable-pcre \
    --enable-start-stop-daemon \
    --with-sqlite3 \
    %{?_with_mysql} \
    %{?_with_pgsql}
# Remove %%{?_smp_mflags} since the docs fail to build with it as of 1.4.3
make

%install
%make_install
# Install fakesmsc and fakewap, useful for monitoring
install -pm0755 test/{fakesmsc,fakewap} %{buildroot}%{_bindir}/
# Logrotate entry
install -pDm0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/kannel
# Unit files
install -pDm0644 %{SOURCE2} %{buildroot}%{_unitdir}/kannel-bearerbox.service
install -pDm0644 %{SOURCE5} %{buildroot}%{_unitdir}/kannel-wapbox.service
install -pDm0644 %{SOURCE6} %{buildroot}%{_unitdir}/kannel-smsbox.service
# Default configuration file
install -pDm0640 %{SOURCE3} %{buildroot}%{_sysconfdir}/kannel.conf
# Empty log directory
mkdir -p %{buildroot}%{_var}/log/kannel/
# Rename start-stop-daemon to start-stop-kannel
mv %{buildroot}%{_sbindir}/start-stop-daemon \
        %{buildroot}%{_sbindir}/start-stop-kannel
# Remove executable bit from man pages (as of 1.4.3)
chmod -c -x %{buildroot}%{_mandir}/man?/*
# Multilib fix : Replace the gw-config with our wrapper script
mv %{buildroot}%{_bindir}/gw-config \
        %{buildroot}%{_bindir}/gw-config.%{_arch}
install -pm0755 %{SOURCE4} %{buildroot}%{_bindir}/gw-config

%pre
getent group kannel >/dev/null || groupadd -r kannel
getent passwd kannel >/dev/null || \
useradd -r -M -g kannel -d %{_var}/lib/kannel kannel -s /sbin/nologin \
    -c "Kannel WAP and SMS gateway" kannel
exit 0

%post
%systemd_post kannel-bearerbox.service
%systemd_post kannel-smsbox.service
%systemd_post kannel-wapbox.service

%preun
%systemd_preun kannel-bearerbox.service
%systemd_preun kannel-smsbox.service
%systemd_preun kannel-wapbox.service

%postun
%systemd_postun_with_restart kannel-bearerbox.service
%systemd_postun_with_restart kannel-smsbox.service
%systemd_postun_with_restart kannel-wapbox.service

%triggerun -- kannel < 1.4.3-8
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply kannel
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save kannel >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del kannel >/dev/null 2>&1 || :
/bin/systemctl try-restart kannel-bearerbox.service >/dev/null 2>&1 || :
/bin/systemctl try-restart kannel-wapbox.service >/dev/null 2>&1 || :
/bin/systemctl try-restart kannel-smsbox.service >/dev/null 2>&1 || :

%files
%doc AUTHORS COPYING ChangeLog NEWS README STATUS
%attr(0640,kannel,kannel) %config(noreplace) %{_sysconfdir}/kannel.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/kannel
%{_unitdir}/kannel-*box.service
%{_bindir}/fakesmsc
%{_bindir}/fakewap
%{_bindir}/mtbatch
%{_bindir}/seewbmp
%{_bindir}/wmlsc
%{_bindir}/wmlsdasm
%{_sbindir}/*
%{_mandir}/man?/*
%attr(0750,kannel,kannel) %dir %{_var}/log/kannel/

%files devel
%{_bindir}/gw-config*
%{_includedir}/kannel/
%{_libdir}/kannel/

%files docs
%doc doc/*/*.pdf

%changelog
* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jul 02 2014 Christopher Meng <rpm@cicku.me> - 1.4.3-20
- NVR bump

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jun 11 2012 Peter Robinson <pbrobinson@fedoraproject.org> - 1.4.3-9
- Add patch for ARM, modernise spec

* Thu May 10 2012 Jon Ciesla <limburgher@gmail.com> - 1.4.3-8
- Migrate to systemd, BZ 789714.

* Fri Feb 10 2012 Petr Pisar <ppisar@redhat.com> - 1.4.3-7
- Rebuild against PCRE 8.30

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec  7 2009 Matthias Saou <http://freshrpms.net/> 1.4.3-4
- Fix gw-config wrapper to actually have it work (#542605).

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 1.4.3-3
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 24 2009 Ville Skyttä <ville.skytta at iki.fi> - 1.4.3-1
- Update to 1.4.3 (#495891).
- Provide -static in -devel.
- Split PDFs into -docs, noarch where applicable.
- Patch to use pkg-config at build time for SSL detection.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.1-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> 1.4.1-10
- rebuild with new openssl

* Mon Dec 22 2008 Matthias Saou <http://freshrpms.net/> 1.4.1-9
- Include patch to fix openssl detection on 64bit.
- Include gw-config wrapper script to fix multilib conflicts (#341701).
- Include patch to remove definitions of types which never happen on Linux.
- Added "INIT INFO" block to the init script (#246964).

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org>
- Autorebuild for GCC 4.3

* Thu Dec 06 2007 Release Engineering <rel-eng at fedoraproject dot org>
- Rebuild for deps

* Wed Aug 22 2007 Matthias Saou <http://freshrpms.net/> 1.4.1-5
- Rebuild for new BuildID feature.

* Mon Aug  6 2007 Matthias Saou <http://freshrpms.net/> 1.4.1-4
- Update License field.
- Switch to using the DESTDIR install method.
- No longer mark init script as config file.
- Remove executable bit from man pages.
- Move gw-config to devel sub-package.

* Thu Dec 14 2006 Matthias Saou <http://freshrpms.net/> 1.4.1-3
- Add ghostscript build requirement, needed (at least on) RHEL4.

* Mon Oct 16 2006 Matthias Saou <http://freshrpms.net/> 1.4.1-2
- Make sure we keep sqlite2 support for FC5 and below.

* Mon Oct  2 2006 Matthias Saou <http://freshrpms.net/> 1.4.1-1
- Update to 1.4.1.
- Remove obsolete depend patch.
- Add 3s sleep sfter bearerbox start to let it settle before connections.
- Switch sqlite backend from sqlite2 to new sqlite3.
- Add conditional --with mysql and pgsql rebuild support.
- Re-enable building the doc since transfig is now available and include PDFs.

* Mon Aug 28 2006 Matthias Saou <http://freshrpms.net/> 1.4.0-9
- FC6 rebuild.

* Mon Mar  6 2006 Matthias Saou <http://freshrpms.net/> 1.4.0-8
- FC5 rebuild.

* Thu Feb  9 2006 Matthias Saou <http://freshrpms.net/> 1.4.0-7
- Rebuild for new gcc/glibc.

* Thu Nov 17 2005 Matthias Saou <http://freshrpms.net/> 1.4.0-6
- Rebuild on FC-5 devel for new openssl library.
- Enable pcre.
- Include at last my pending improvements (detail below).
- Include (at last!) user creation, logrotate entry and init script.
- Include default configuration file (do nothing, access only from 127.0.0.1).
- Include empty log directory.
- Include fakesmsc and fakewap programs, useful for monitoring purposes.

* Wed May 25 2005 Jeremy Katz <katzj@redhat.com> - 1.4.0-5
- rebuild with change to depend on sqlite2 (#156229)

* Fri Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Mon Jan 17 2005 Matthias Saou <http://freshrpms.net/> 1.4.0-3
- Added Stefan Radman's patch for kannel bug #173 to fix .depend problem.

* Fri Dec 10 2004 Matthias Saou <http://freshrpms.net/> 1.4.0-1
- Update to 1.4.0.
- Remove the obsolete OpenSSL workaround.

* Thu Nov  4 2004 Matthias Saou <http://freshrpms.net/> 1.3.2-4
- Added pcre support, doc building (almost) and sqlite backend...
  it still fails with a corrupt first line of .depend on FC3, though.

* Tue Aug 24 2004 Matthias Saou <http://freshrpms.net/> 1.3.2-2
- Really comment out all scriplets, they're not yet used.

* Thu Jul 29 2004 Matthias Saou <http://freshrpms.net/> 1.3.2-1
- Don't fix the openssl detection for RHL 7.x.

* Thu Jul 22 2004 Matthias Saou <http://freshrpms.net/> 1.3.2-0
- Update to 1.3.2 development version.
- Added -devel sub-package since there are now headers and a static lib.

* Wed Jul 14 2004 Matthias Saou <http://freshrpms.net/> 1.2.1-0
- Initial RPM release, still need to add an init script I think.

